==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/FirstStart/ts/FirstStart_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+35"/>
        <location line="+216"/>
        <source>%1 First Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pierwszy start</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Czarny / Biały
Bardzo gruby</translatorcomment>
        <translation type="unfinished">Bardzo gruby</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Czarny / Biały
Biały</translatorcomment>
        <translation type="unfinished">Biały</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Language:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Język interfejsu graficznego:
Język komend:
Język poleceń:</translatorcomment>
        <translation type="unfinished">Język:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welcome to %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Witamy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Proszę wybrać ustawienia wykorzystywane dla nowych rysunków. Wszystkie te ustawienia można zmienić później w oknie dialogowym Preferencje.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Jednostka domyślna:
&amp;Główna jednostka rysowania:</translatorcomment>
        <translation type="unfinished">Jednostka:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Domyślny rozmiar papieru:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przecinku:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Kolor tła:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/FirstStart/ts/FirstStart_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+36"/>
        <location line="+217"/>
        <source>%1 First Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pierwsze uruchomienie %1</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Czarny / Biały
Bardzo gruby</translatorcomment>
        <translation>Czarny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Czarny / Biały
Biały</translatorcomment>
        <translation>Biały</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Language:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Język interfejsu graficznego:
Język komend:
Język poleceń:</translatorcomment>
        <translation>Język:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welcome to %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Witamy w %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wybrać ustawienia używane dla nowych rysunków. Wszystkie te ustawienia można zmienić później w oknie Preferencji.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Jednostka domyślna:
&amp;Główna jednostka rysowania:</translatorcomment>
        <translation>Jednostka:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Domyślny rozmiar papieru:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Separator dziesiętny:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Kolor tła:</translation>
    </message>
</context>
</TS>
